.. vim: set fileencoding=utf-8 :
.. author: Manuel Günther <manuel.guenther@idiap.ch>
.. date: Thu Sep 20 11:58:57 CEST 2012

.. This file contains all links we use for documentation in a centralized place

.. _idiap: https://www.idiap.ch
.. _bob: https://www.idiap.ch/software/bob
.. _idiap at gitlab: https://gitlab.idiap.ch/bob
.. _at&t database: http://www.cl.cam.ac.uk/research/dtg/attarchive/facedatabase.html
.. _buildout: http://www.buildout.org
.. _setuptools: http://trac.edgewall.org/wiki/setuptools
.. _nist: http://www.nist.gov/itl/iad/ig/focs.cfm
.. _pypi: http://pypi.python.org
.. _sge: http://wiki.idiap.ch/linux/SunGridEngine
.. _virtualbox: https://www.virtualbox.org
.. _hdf5: http://www.hdfgroup.org/HDF5
.. _mailing list: https://www.idiap.ch/software/bob/discuss
.. _packages: https://www.idiap.ch/software/bob/packages
.. _bobinstall: https://www.idiap.ch/software/bob/install
.. _conda: https://conda.io
.. _biometric recognition databases: https://www.idiap.ch/software/bob/packages/#biometric-recognition-database-frontends
